@@ -11,6 +11,7 @@ from rest_framework.reverse import reverse
 
 from .utils import get_layer_group_cache_key
 from .schema import JSONSchemaValidator, SCENE_LAYERTREE
+from .style import generate_style_from_wizard
 
 
 class Scene(models.Model):
@@ -28,6 +29,7 @@ class Scene(models.Model):
     tree = JSONField(
         default=list, validators=[JSONSchemaValidator(limit_value=SCENE_LAYERTREE)]
     )
+    config = JSONField(default=dict)
 
     def get_absolute_url(self):
         return reverse("scene-detail", args=[self.pk])
@@ -77,29 +79,39 @@ class Scene(models.Model):
             layer.order = order
             layer.save()
 
-    def insert_in_tree(self, layer, parts):
+    def insert_in_tree(self, layer, parts, group_config=None):
         """ Add the layer in tree. Each parts are a group name to find inside the tree.
             Here we assume that missing groups are added at first position of current node
             We create missing group with default exclusive group configuration (should be corrected later if necessary)
         """
 
+        group_config = group_config or {}
+
         current_node = self.tree
+        last_group = None
         for part in parts:
             found = False
+            # Search in groups
             for group in current_node:
                 if group.get("group") and group["label"] == part:
+                    last_group = group
                     current_node = group["children"]
                     found = True
                     break
             if not found:
-                # Add the missing group
+                # Add the missing group part
                 new_group = {"group": True, "label": part, "children": []}
-                current_node.insert(0, new_group)
+                current_node.append(new_group)
+                last_group = new_group
                 current_node = new_group["children"]
 
         # Node if found (or created) we can add the geolayer now
         current_node.append({"geolayer": layer.id, "label": layer.name})
 
+        if group_config and last_group:
+            # And update tho config
+            last_group.update(group_config)
+
         self.save()
 
     def save(self, *args, **kwargs):
@@ -138,6 +150,7 @@ class Layer(models.Model):
         LayerGroup, on_delete=models.SET_NULL, null=True, related_name="layers"
     )
     name = models.CharField(max_length=255, blank=False)
+    # Whether the layer is shown in tree or hidden
     in_tree = models.BooleanField(default=True)
 
     order = models.IntegerField(default=0)
@@ -145,6 +158,7 @@ class Layer(models.Model):
     description = models.TextField(blank=True)
 
     layer_style = JSONField(default=dict)
+    layer_style_wizard = JSONField(default=dict)
     settings = JSONField(default=dict)
     active_by_default = models.BooleanField(default=False)
 
@@ -182,6 +196,17 @@ class Layer(models.Model):
         ordering = ("order", "name")
 
     def save(self, **kwargs):
+        if self.layer_style_wizard:
+            style, legend_addition = generate_style_from_wizard(
+                self, self.layer_style_wizard
+            )
+            self.layer_style = style
+            if not self.legends:
+                legend_addition["title"] = self.name
+                self.legends = [legend_addition]
+            else:
+                self.legends[0].update(legend_addition)
+
         super().save(**kwargs)
 
         # Invalidate cache for layer group
@@ -222,8 +247,17 @@ class FilterField(models.Model):
     filter_settings = JSONField(default=dict)
     format_type = models.CharField(max_length=255, default=None, null=True)
 
+    # Whether the field can be exported
     exportable = models.BooleanField(default=False)
+
+    # Whether the field is available in the table
     shown = models.BooleanField(default=False)
 
+    # Whether the field is displayed by default in table
+    display = models.BooleanField(default=True)
+
+    # Config for all non handled things
+    settings = JSONField(default=dict)
+
     class Meta:
         ordering = ("order",)
