@@ -1,15 +1,14 @@
 from django.urls import include, path
-from django.conf.urls import url
 from rest_framework import routers
 
 from .geostore import urlpatterns as geostore_patterns
 from .geosource import router as geosource_router
-from ..views import LayerViewset, LayerView, SceneViewset, GeoSourceModelViewset
+from ..views import LayerViewset, LayerView, SceneViewset
 
 router = routers.SimpleRouter()
 
-router.register(r"geolayer/scene", SceneViewset, base_name="scene")
-router.register(r"geolayer/", LayerViewset, base_name="layer")
+router.register(r"geolayer/scene", SceneViewset, basename="scene")
+router.register(r"geolayer", LayerViewset, basename="layer")
 
 # Extras viewsets
 
